@@ -11,7 +11,7 @@
 
 (gettextize --version) < /dev/null > /dev/null 2>&1 || {
         echo;
-        echo "You must have gettext installed to compile XMMS";
+        echo "You must have gettext installed to compile bio2jack";
         echo;
         exit;
 }
@@ -31,8 +31,8 @@
 }
 
 
-#echo " Running libtoolize, please ignore non-fatal messages"
-#echo n|libtoolize --copy --force || exit;
+echo " Running libtoolize, please ignore non-fatal messages"
+echo n|libtoolize --copy --force || exit;
 echo "Generating configuration files for bio2jack, please wait..."
 echo;
 
